{"00000:1": "

    \n

\n", "00003:source": "

    source:\n    - .txt\n    - .md\n    - "*/_*.html|pyg|-":\n        - canon : True\n        - ws_template : False\n

\n", "00002:assets": "

    assets:\n    - .css\n    - .js\n    - .png\n    - .jpg\n

\n", "00001:docs": "

    docs:\n    - index.html|jinja|markdown|htmlsections:\n        - ws_template : '_home_template.html'\n    - .md|jinja|markdown:\n        - meta\n        - source\n

\n", "00004:meta": "

    meta:\n    - list-reports.sh|shint|pyg:\n        - contents : "dexy reporters"\n    - .jinja|pyg\n    - .yaml|idio\n    - .html|pyg\n    - .md|idio:\n        - idio: { lexer : jinja }\n    - dexy.conf|pyg:\n        - pyg: { lexer : yaml }\n

\n"}